@@ -44,11 +44,11 @@ struct _AviPcm
     avi_edit,AVI編集ハンドル
          RET,AVIPCM構造体,NULL:エラー                                       */
 AviPcm *
-avi_get_pcm_open (AviEdit *avi_edit)
+avi_pcm_open (AviEdit *avi_edit)
 {
   AviPcm *avi_pcm;
 
-  if (!avi_edit || avi_type (avi_edit) != AVI_TYPE_AUDIO)
+  if (!avi_edit || avi_edit_type (avi_edit) != AVI_TYPE_AUDIO)
     return NULL;
   avi_pcm = g_malloc0 (sizeof (AviPcm));
   avi_pcm->avi_edit = avi_edit;
@@ -62,7 +62,7 @@ avi_get_pcm_open (AviEdit *avi_edit)
     avi_pcm,AVIPCM構造体
         RET,TRUE:正常終了,FALSE:エラー                                      */
 gboolean
-avi_get_pcm_close (AviPcm *avi_pcm)
+avi_pcm_close (AviPcm *avi_pcm)
 {
   gboolean result;
 
@@ -82,9 +82,9 @@ avi_get_pcm_close (AviPcm *avi_pcm)
             buf,追加するデータ
         samples,追加するデータの実サンプル数                                */
 static void
-avi_get_pcm_add_buffer (AviPcm        *avi_pcm,
-                        gconstpointer  buf,
-                        const gint     samples)
+avi_pcm_add_buffer (AviPcm        *avi_pcm,
+                    gconstpointer  buf,
+                    const gsize    samples)
 {
   avi_pcm->tmp_buf = g_realloc (avi_pcm->tmp_buf,
                             (avi_pcm->tmp_samples + samples)
@@ -104,11 +104,11 @@ avi_get_pcm_add_buffer (AviPcm        *avi_pcm,
     out_samples,PCMデータの実サンプル数
             RET,TRUE:正常終了,FALSE:エラー                                  */
 gboolean
-avi_get_pcm (AviPcm     *avi_pcm,
-             const gint  start,
-             const gint  samples,
-             gpointer   *out_buf,
-             gint       *out_samples)
+avi_pcm_get_raw (AviPcm      *avi_pcm,
+                 const gint   start,
+                 const gsize  samples,
+                 gpointer    *out_buf,
+                 gsize       *out_samples)
 {
   gpointer result_buf;
   gint pcm_samples, virtual_samples, result_samples, result_bytes, tmp_bytes;
@@ -117,12 +117,14 @@ avi_get_pcm (AviPcm     *avi_pcm,
   if (!avi_pcm)
     return FALSE;
   avi_edit = avi_pcm->avi_edit;
-  if (start < 0 || avi_length (avi_edit) < start + samples || samples <= 0)
+  if (start < 0 || avi_edit_length (avi_edit) < start + samples
+                                                            || samples <= 0)
     return FALSE;                   /* ja:範囲外 */
   if (avi_pcm->pos == start)
     {
-      pcm_samples = avi_audio_virtual_2_real (avi_pcm->in_samples + samples,
-                                        avi_edit->wfx) - avi_pcm->out_samples;
+      pcm_samples = avi_audio_real_from_virtual_roundup
+                                (avi_pcm->in_samples + samples, avi_edit->wfx)
+                                                        - avi_pcm->out_samples;
       if (avi_pcm->marker < 0)
         {
           if (out_buf)
@@ -167,20 +169,22 @@ avi_get_pcm (AviPcm     *avi_pcm,
           avi_pcm->marker = -1;
           return FALSE;
         }
-      avi_get_file (avi_edit, start);/* ja:AVIファイルを求める */
+      avi_base_get_file (avi_edit, start);/* ja:AVIファイルを求める */
       avi_pcm->file = avi_edit->file;
-      avi_pcm->marker = avi_audio_virtual_to_real
+      avi_pcm->marker = avi_audio_real_from_virtual
                                 (start - avi_edit->offset, avi_pcm->file->wfx);
-      pcm_samples = avi_audio_virtual_2_real (samples, avi_edit->wfx);
+      pcm_samples = avi_audio_real_from_virtual_roundup
+                                                    (samples, avi_edit->wfx);
       virtual_samples = samples;
     }
   while (avi_pcm->tmp_samples < pcm_samples)
     {
       gpointer file_buf, conv_buf;
-      gint file_length, file_samples, conv_samples;
+      gsize file_length, file_samples, conv_samples;
 
-      file_length = CLAMP (avi_audio_virtual_2_real (avi_pcm->file->length,
-                            avi_pcm->file->wfx), 1, avi_pcm->file->samples);
+      file_length = CLAMP (avi_audio_real_from_virtual_roundup
+                                (avi_pcm->file->length, avi_pcm->file->wfx),
+                                                    1, avi_pcm->file->samples);
       if (avi_pcm->marker >= file_length)
         {
           avi_pcm->file = avi_pcm->file->next;
@@ -191,7 +195,7 @@ avi_get_pcm (AviPcm     *avi_pcm,
               if (avi_pcm->acm_object)
                 {
                   gpointer e_buf = NULL;
-                  gint e_samples;
+                  gsize e_samples;
 
                   if ((!acm_decompress_end (avi_pcm->acm_object,
                                                             &e_buf, &e_samples)
@@ -217,7 +221,7 @@ avi_get_pcm (AviPcm     *avi_pcm,
                     }
                   g_free (e_buf);
                   avi_pcm->acm_object = NULL;
-                  avi_get_pcm_add_buffer (avi_pcm, conv_buf, conv_samples);
+                  avi_pcm_add_buffer (avi_pcm, conv_buf, conv_samples);
                   g_free (conv_buf);
                 }
               if (avi_pcm->wcv
@@ -236,17 +240,18 @@ avi_get_pcm (AviPcm     *avi_pcm,
                   avi_pcm->marker = -1;
                   return FALSE;
                 }
-              avi_get_pcm_add_buffer (avi_pcm, conv_buf, conv_samples);
+              avi_pcm_add_buffer (avi_pcm, conv_buf, conv_samples);
               avi_pcm->wcv = NULL;
               g_free (avi_pcm->wfx);
               avi_pcm->wfx = NULL;
               break;
             }
-          file_length = CLAMP (avi_audio_virtual_2_real (avi_pcm->file->length,
-                            avi_pcm->file->wfx), 1, avi_pcm->file->samples);
+          file_length = CLAMP (avi_audio_real_from_virtual_roundup
+                                (avi_pcm->file->length, avi_pcm->file->wfx),
+                                                    1, avi_pcm->file->samples);
           avi_pcm->marker = 0;
         }
-      file_samples = CLAMP (avi_audio_virtual_to_real (virtual_samples,
+      file_samples = CLAMP (avi_audio_real_from_virtual (virtual_samples,
                         avi_pcm->file->wfx), 1, file_length - avi_pcm->marker);
       file_buf = g_malloc (avi_read_audio_size (avi_pcm->file,
                                             avi_pcm->marker, file_samples));
@@ -281,7 +286,7 @@ avi_get_pcm (AviPcm     *avi_pcm,
           if (avi_pcm->acm_object)
             {
               gpointer e_buf = NULL;
-              gint e_samples;
+              gsize e_samples;
 
               if ((!acm_decompress_end (avi_pcm->acm_object,
                                                             &e_buf, &e_samples)
@@ -308,7 +313,7 @@ avi_get_pcm (AviPcm     *avi_pcm,
                 }
               g_free (e_buf);
               avi_pcm->acm_object = NULL;
-              avi_get_pcm_add_buffer (avi_pcm, conv_buf, conv_samples);
+              avi_pcm_add_buffer (avi_pcm, conv_buf, conv_samples);
               g_free (conv_buf);
             }
           if (wfx_get_format_tag (avi_pcm->file->wfx) != WAVE_FMT_PCM)
@@ -372,7 +377,7 @@ avi_get_pcm (AviPcm     *avi_pcm,
                       return FALSE;
                     }
                   avi_pcm->wcv = NULL;
-                  avi_get_pcm_add_buffer (avi_pcm, conv_buf, conv_samples);
+                  avi_pcm_add_buffer (avi_pcm, conv_buf, conv_samples);
                 }
               avi_pcm->wcv = wave_convert_begin
                             (wfx ? wfx : avi_pcm->file->wfx, avi_edit->wfx);
@@ -403,7 +408,7 @@ avi_get_pcm (AviPcm     *avi_pcm,
       if (avi_pcm->acm_object)
         {
           gpointer e_buf = NULL;
-          gint e_samples;
+          gsize e_samples;
 
           if (!acm_decompress (avi_pcm->acm_object,
                                     file_buf, file_samples, &e_buf, &e_samples)
@@ -449,7 +454,7 @@ avi_get_pcm (AviPcm     *avi_pcm,
           return FALSE;
         }
       g_free (file_buf);
-      avi_get_pcm_add_buffer (avi_pcm, conv_buf, conv_samples);
+      avi_pcm_add_buffer (avi_pcm, conv_buf, conv_samples);
       g_free (conv_buf);
       avi_pcm->marker += file_samples;
       virtual_samples -= file_samples;
@@ -467,7 +472,7 @@ avi_get_pcm (AviPcm     *avi_pcm,
 
       silent_samples = pcm_samples - avi_pcm->tmp_samples;
       silent_buf = wave_fill_silent_pcm (avi_edit->wfx, silent_samples);
-      avi_get_pcm_add_buffer (avi_pcm, silent_buf, silent_samples);
+      avi_pcm_add_buffer (avi_pcm, silent_buf, silent_samples);
       g_free (silent_buf);
     }
   result_samples = MIN (avi_pcm->tmp_samples, pcm_samples);
