@@ -18,6 +18,9 @@
 */
 #include "avibase.h"
 #include "aviplay.h"
+#ifdef USE_LIBAO
+# include <ao/ao.h>
+#endif /* USE_LIBAO */
 #ifdef USE_ALSA
 # include <alsa/asoundlib.h>
 #endif /* USE_ALSA */
@@ -296,6 +299,77 @@ avi_play_timeout (AviPlay *play)
 }
 
 
+#ifdef USE_LIBAO
+/* ja:スレッド */
+static gpointer
+avi_play_libao (AviPlay *play)
+{
+  ao_sample_format format;
+  ao_device *device;
+
+  format.bits = avi_edit_get_bits_per_sample (play->avi_edit[1]);
+  format.rate = avi_edit_get_samples_per_sec (play->avi_edit[1]);
+  format.channels = avi_edit_get_channels (play->avi_edit[1]);
+  format.byte_format = AO_FMT_LITTLE;
+  device = ao_open_live (play->driver_id, &format, NULL);
+  if (device)
+    {
+      gint start, length;
+
+      start = play->avi_edit[0] ? avi_time_sync_sample (play->avi_edit[0],
+                                play->start, play->avi_edit[1]) : play->start;
+      length = avi_edit_length (play->avi_edit[1]);
+      while (play->playing && play->pos < length)
+        {
+          gint pos;
+          gsize samples;
+
+          pos = MIN (length, g_timer_elapsed (play->gtimer, NULL)
+                                            * AVI_PCM_SAMPLES_PER_SEC + start);
+          if (play->pos < pos)
+            play->pos = pos;
+          samples = pos + AVI_PCM_BUFFER_LENGTH * AVI_PCM_BUFFER_NUM
+                                                                - play->pos;
+          if (samples > length - play->pos)
+            samples = length - play->pos;
+          else if (samples < AVI_PCM_BUFFER_LENGTH)
+            samples = 0;
+          if (samples > 0)
+            {
+              gpointer out_buf;
+              gsize out_samples;
+
+              if (!avi_pcm_get_raw (play->avi_pcm,
+                                play->pos, samples, &out_buf, &out_samples))
+                break;
+              if (out_samples > 0)
+                {
+                  gboolean result;
+                  gsize bytes;
+
+                  bytes = out_samples * play->block_align;
+                  if (format.bits == 8)
+                    {
+                      gint i;
+
+                      for (i = 0; i < bytes; i++)
+                        ((gint8 *)out_buf)[i] = ((guint8 *)out_buf)[i] - 128;
+                    }
+                  result = ao_play (device, out_buf, bytes);
+                  g_free (out_buf);
+                  play->pos += samples;
+                  if (!result)
+                    break;
+                }
+            }
+        }
+      ao_close (device);
+    }
+  return NULL;
+}
+#endif /* USE_LIBAO */
+
+
 #ifdef USE_ALSA
 /* ja:スレッド */
 static gpointer
@@ -305,7 +379,7 @@ avi_play_alsa (AviPlay *play)
   snd_pcm_uframes_t uframes = 0;
   snd_pcm_t *handle;
 
-  if (play->avi_edit[1] && snd_pcm_open (&handle, "default",
+  if (snd_pcm_open (&handle, "default",
                             SND_PCM_STREAM_PLAYBACK, SND_PCM_NONBLOCK) == 0)
     {
       snd_pcm_hw_params_t *hw_params;
@@ -588,6 +662,9 @@ avi_play_destroy (GtkObject *object)
   avi_edit_close (play->avi_edit[0]);
   avi_edit_close (play->avi_edit[1]);
   play->avi_edit[0] = play->avi_edit[1] = NULL;
+#ifdef USE_LIBAO
+  ao_shutdown ();
+#endif /* USE_LIBAO */
 #ifdef G_OS_WIN32
   if (play->hWnd)
     {
@@ -620,6 +697,11 @@ avi_play_init (AviPlay *play)
   play->avi_edit[0] = play->avi_edit[1] = NULL;
   play->avi_frame = NULL;
   play->avi_pcm = NULL;
+#ifdef USE_LIBAO
+  ao_initialize ();
+  play->driver_id = ao_default_driver_id ();
+  play->thread = NULL;
+#endif /* USE_LIBAO */
 #ifdef USE_ALSA
   play->err = NULL;
   play->thread = NULL;
@@ -1350,6 +1432,17 @@ avi_play_play (AviPlay *play)
   else
     play->timer_id = g_timeout_add_full (G_PRIORITY_LOW, 100,
                                     (GSourceFunc)avi_play_timeout, play, NULL);
+#ifdef USE_LIBAO
+  if (play->driver_id >= 0 && play->avi_edit[1]
+                        && (play->avi_pcm = avi_pcm_open (play->avi_edit[1])))
+    {
+      play->pos = play->avi_edit[0] ? avi_time_sync_sample (play->avi_edit[0],
+                                            play->position, play->avi_edit[1])
+                                                            : play->position;
+      play->thread = g_thread_create ((GThreadFunc)avi_play_libao, play,
+                                                                TRUE, NULL);
+    }
+#endif /* USE_LIBAO */
 #ifdef USE_ALSA
   if (play->avi_edit[1] && (play->avi_pcm = avi_pcm_open (play->avi_edit[1])))
     {
@@ -1442,14 +1535,22 @@ avi_play_stop (AviPlay *play)
       gtk_timeout_remove (play->timer_id);
       play->timer_id = 0;
     }
+#ifdef USE_LIBAO
+  if (play->thread)
+    {
+      g_thread_join (play->thread);
+      play->thread = NULL;
+      play->pos = -1;
+    }
+#endif /* USE_LIBAO */
 #ifdef USE_ALSA
   if (play->thread)
     {
-      play->pos = -1;
       g_thread_join (play->thread);
       g_free (play->err);
       play->err = NULL;
       play->thread = NULL;
+      play->pos = -1;
     }
 #endif /* USE_ALSA */
 #ifdef G_OS_WIN32
