@@ -1,6 +1,6 @@
 /*
     avicore
-    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -28,10 +28,11 @@ extern "C" {
 #endif /* __cplusplus */
 
 
-#define BI_COMP_RGB         0
-#define BI_COMP_RLE8        1
-#define BI_COMP_RLE4        2
-#define BI_COMP_BITFIELDS   3
+#define BF_TYPE 0x4d42
+#define BI_COMP_RGB       0
+#define BI_COMP_RLE8      1
+#define BI_COMP_RLE4      2
+#define BI_COMP_BITFIELDS 3
 
 
 #define BMFH_SIZE 14
@@ -298,105 +299,105 @@ typedef struct _RgbQuad { guint8 dummy[RGBQUAD_SIZE]; } RgbQuad;
       rgb,パレットを格納するバッファ
     table,パレット分布立方体                                                */
 void
-bitmap_make_palette (const gint  count,
-                     RgbQuad    *rgb,
-                     guint       table[32][32][32]);
+bitmap_make_palette (const gint   count,
+                     RgbQuad     *rgb,
+                     const guint  table[32][32][32]);
 
 
 /*  ja:圧縮されたビットマップを復元する
     bmih0,元のビットマップへのポインタ
     bmih1,新しいビットマップへのポインタ                                    */
 void
-bitmap_expand (BitmapInfoHeader *bmih0,
-               BitmapInfoHeader *bmih1);
+bitmap_expand (const BitmapInfoHeader *bmih0,
+               BitmapInfoHeader       *bmih1);
 
 
 /*  ja:フルカラー/32ビットビットマップを1ビットビットマップに変換する(近似)
     bmih0,元のビットマップへのポインタ
     bmih1,新しいビットマップへのポインタ                                    */
 void
-bitmap_approx_1 (BitmapInfoHeader *bmih0,
-                 BitmapInfoHeader *bmih1);
+bitmap_approx_1 (const BitmapInfoHeader *bmih0,
+                 BitmapInfoHeader       *bmih1);
 
 
 /*  ja:フルカラー/32ビットビットマップを4ビットビットマップに変換する(近似)
     bmih0,元のビットマップへのポインタ
     bmih1,新しいビットマップへのポインタ                                    */
 void
-bitmap_approx_4 (BitmapInfoHeader *bmih0,
-                 BitmapInfoHeader *bmih1);
+bitmap_approx_4 (const BitmapInfoHeader *bmih0,
+                 BitmapInfoHeader       *bmih1);
 
 
 /*  ja:フルカラー/32ビットビットマップを8ビットビットマップに変換する(近似)
     bmih0,元のビットマップへのポインタ
     bmih1,新しいビットマップへのポインタ                                    */
 void
-bitmap_approx_8 (BitmapInfoHeader *bmih0,
-                 BitmapInfoHeader *bmih1);
+bitmap_approx_8 (const BitmapInfoHeader *bmih0,
+                 BitmapInfoHeader       *bmih1);
 
 
 /*  ja:フルカラー/32ビットビットマップを1ビットビットマップに変換する(誤差拡散)
     pbmih0,元のビットマップへのポインタ
     pbmih1,新しいビットマップへのポインタ                                   */
 void
-bitmap_diffuse_1 (BitmapInfoHeader *bmih0,
-                  BitmapInfoHeader *bmih1);
+bitmap_diffuse_1 (const BitmapInfoHeader *bmih0,
+                  BitmapInfoHeader       *bmih1);
 
 
 /*  ja:フルカラー/32ビットビットマップを4ビットビットマップに変換する(誤差拡散)
     bmih0,元のビットマップへのポインタ
     bmih1,新しいビットマップへのポインタ                                    */
 void
-bitmap_diffuse_4 (BitmapInfoHeader *bmih0,
-                  BitmapInfoHeader *bmih1);
+bitmap_diffuse_4 (const BitmapInfoHeader *bmih0,
+                  BitmapInfoHeader       *bmih1);
 
 
 /*  ja:フルカラー/32ビットビットマップを8ビットビットマップに変換する(誤差拡散)
     bmih0,元のビットマップへのポインタ
     bmih1,新しいビットマップへのポインタ                                    */
 void
-bitmap_diffuse_8 (BitmapInfoHeader *bmih0,
-                  BitmapInfoHeader *bmih1);
+bitmap_diffuse_8 (const BitmapInfoHeader *bmih0,
+                  BitmapInfoHeader       *bmih1);
 
 
 /*  ja:フルカラー/32ビットビットマップを1ビットビットマップに変換する(識域)
     bmih0,元のビットマップへのポインタ
     bmih1,新しいビットマップへのポインタ                                    */
 void
-bitmap_order_1 (BitmapInfoHeader *bmih0,
-                BitmapInfoHeader *bmih1);
+bitmap_order_1 (const BitmapInfoHeader *bmih0,
+                BitmapInfoHeader       *bmih1);
 
 
 /*  ja:フルカラー/32ビットビットマップを4ビットビットマップに変換する(識域)
     bmih0,元のビットマップへのポインタ
     bmih1,新しいビットマップへのポインタ                                    */
 void
-bitmap_order_4 (BitmapInfoHeader *bmih0,
-                BitmapInfoHeader *bmih1);
+bitmap_order_4 (const BitmapInfoHeader *bmih0,
+                BitmapInfoHeader       *bmih1);
 
 
 /*  ja:フルカラー/32ビットビットマップを8ビットビットマップに変換する(識域)
     bmih0,元のビットマップへのポインタ
     bmih1,新しいビットマップへのポインタ                                    */
 void
-bitmap_order_8 (BitmapInfoHeader *bmih0,
-                BitmapInfoHeader *bmih1);
+bitmap_order_8 (const BitmapInfoHeader *bmih0,
+                BitmapInfoHeader       *bmih1);
 
 
 /*  ja:フルカラー/32ビットビットマップを16ビットビットマップに変換する
     bmih0,元のビットマップへのポインタ
     bmih1,新しいビットマップへのポインタ                                    */
 void
-bitmap_convert_16 (BitmapInfoHeader *bmih0,
-                   BitmapInfoHeader *bmih1);
+bitmap_convert_16 (const BitmapInfoHeader *bmih0,
+                   BitmapInfoHeader       *bmih1);
 
 
 /*  ja:ビットマップをフルカラービットマップに変換する
     bmih0,元のビットマップへのポインタ
     bmih1,新しいビットマップへのポインタ                                    */
 void
-bitmap_convert_24 (BitmapInfoHeader *bmih0,
-                   BitmapInfoHeader *bmih1);
+bitmap_convert_24 (const BitmapInfoHeader *bmih0,
+                   BitmapInfoHeader       *bmih1);
 
 
 /*  ja:32ビットビットマップをフルカラービットマップに変換する
@@ -404,73 +405,73 @@ bitmap_convert_24 (BitmapInfoHeader *bmih0,
     bmih1,新しいビットマップへのポインタ
       rgb,背景色                                                            */
 void
-bitmap_convert_24_with_bgcolor (BitmapInfoHeader *bmih0,
-                                BitmapInfoHeader *bmih1,
-                                RgbQuad          *rgb);
+bitmap_convert_24_with_bgcolor (const BitmapInfoHeader *bmih0,
+                                BitmapInfoHeader       *bmih1,
+                                const RgbQuad          *rgb);
 
 
 /*  ja:ビットマップを32ビットビットマップに変換する
     bmih0,元のビットマップへのポインタ
     bmih1,新しいビットマップへのポインタ                                    */
 void
-bitmap_convert_32 (BitmapInfoHeader *bmih0,
-                   BitmapInfoHeader *bmih1);
+bitmap_convert_32 (const BitmapInfoHeader *bmih0,
+                   BitmapInfoHeader       *bmih1);
 
 
 /*  ja:1ビットビットマップのサイズを変更する
     bmih0,元のビットマップへのポインタ
     bmih1,新しいビットマップへのポインタ                                    */
 void
-bitmap_zoom_1 (BitmapInfoHeader *bmih0,
-               BitmapInfoHeader *bmih1);
+bitmap_zoom_1 (const BitmapInfoHeader *bmih0,
+               BitmapInfoHeader       *bmih1);
 
 
 /*  ja:4ビットビットマップのサイズを変更する
     bmih0,元のビットマップへのポインタ
     bmih1,新しいビットマップへのポインタ                                    */
 void
-bitmap_zoom_4 (BitmapInfoHeader *bmih0,
-               BitmapInfoHeader *bmih1);
+bitmap_zoom_4 (const BitmapInfoHeader *bmih0,
+               BitmapInfoHeader       *bmih1);
 
 
 /*  ja:8ビットビットマップのサイズを変更する
     bmih0,元のビットマップへのポインタ
     bmih1,新しいビットマップへのポインタ                                    */
 void
-bitmap_zoom_8 (BitmapInfoHeader *bmih0,
-               BitmapInfoHeader *bmih1);
+bitmap_zoom_8 (const BitmapInfoHeader *bmih0,
+               BitmapInfoHeader       *bmih1);
 
 
 /*  ja:16ビットビットマップのサイズを変更する
     bmih0,元のビットマップへのポインタ
     bmih1,新しいビットマップへのポインタ                                    */
 void
-bitmap_zoom_16 (BitmapInfoHeader *bmih0,
-                BitmapInfoHeader *bmih1);
+bitmap_zoom_16 (const BitmapInfoHeader *bmih0,
+                BitmapInfoHeader       *bmih1);
 
 
 /*  ja:フルカラービットマップのサイズを変更する
     bmih0,元のビットマップへのポインタ
     bmih1,新しいビットマップへのポインタ                                    */
 void
-bitmap_zoom_24 (BitmapInfoHeader *bmih0,
-                BitmapInfoHeader *bmih1);
+bitmap_zoom_24 (const BitmapInfoHeader *bmih0,
+                BitmapInfoHeader       *bmih1);
 
 
 /*  ja:32ビットビットマップのサイズを変更する
     bmih0,元のビットマップへのポインタ
     bmih1,新しいビットマップへのポインタ                                    */
 void
-bitmap_zoom_32 (BitmapInfoHeader *bmih0,
-                BitmapInfoHeader *bmih1);
+bitmap_zoom_32 (const BitmapInfoHeader *bmih0,
+                BitmapInfoHeader       *bmih1);
 
 
 /*  ja:ビットマップのサイズを変更する
     bmih0,元のビットマップへのポインタ
     bmih1,新しいビットマップへのポインタ                                    */
 void
-bitmap_zoom (BitmapInfoHeader *bmih0,
-             BitmapInfoHeader *bmih1);
+bitmap_zoom (const BitmapInfoHeader *bmih0,
+             BitmapInfoHeader       *bmih1);
 
 
 /*  ja:32ビットビットマップを重ね合わせる
@@ -480,11 +481,11 @@ bitmap_zoom (BitmapInfoHeader *bmih0,
     y_overlay,X座標
         trans,透過色,TRUE:有効,FALSE:無効                                   */
 void
-bitmap_overlay_32 (BitmapInfoHeader *bmih0,
-                   BitmapInfoHeader *bmih1,
-                   gint              x_overlay,
-                   gint              y_overlay,
-                   gboolean          trans);
+bitmap_overlay_32 (const BitmapInfoHeader *bmih0,
+                   BitmapInfoHeader       *bmih1,
+                   const gint              x_overlay,
+                   const gint              y_overlay,
+                   const gboolean          trans);
 
 
 #ifdef __cplusplus
