@@ -215,7 +215,7 @@ wave_convert_samples_per_sec (WaveConvSamplesPerSec *wcs,
   gint i, j, d, block_align, pos;
 
   block_align = wcs->channels * wcs->bits_per_sample / 8;
-  samples = (glonglong)((wcs->in_samples + in_samples) * wcs->samples_per_sec1
+  samples = ((glonglong)(wcs->in_samples + in_samples) * wcs->samples_per_sec1
     + wcs->samples_per_sec0 - 1) / wcs->samples_per_sec0 - wcs->out_samples;
   result = g_malloc (samples * block_align);
   if (wcs->bits_per_sample == 8)
@@ -310,8 +310,8 @@ wave_convert_samples_per_sec_end (WaveConvSamplesPerSec *wcs,
   gsize samples;
   gint i, j, d;
 
-  samples = (glonglong)(wcs->in_samples * wcs->samples_per_sec1
-    + wcs->samples_per_sec0 - 1) / wcs->samples_per_sec0 - wcs->out_samples;
+  samples = MAX (0, (glonglong)(wcs->in_samples * wcs->samples_per_sec1
+    + wcs->samples_per_sec0 - 1) / wcs->samples_per_sec0 - wcs->out_samples);
   result = g_malloc (samples * (wcs->channels * wcs->bits_per_sample / 8));
   if (wcs->bits_per_sample == 8)
     {
